/*
 * Copyright(c) 1997,1998,1999 - All Rights Reserved
 *
 * See the COPYRIGHT file.
 */

void	display_input();
void	sic_getch();
int	cmd_run(char *);
